@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -24,17 +24,18 @@
 #include "SDL_error.h"
 #include "SDL_hints_c.h"
 
-
 /* Assuming there aren't many hints set and they aren't being queried in
    critical performance paths, we'll just use linked lists here.
  */
-typedef struct SDL_HintWatch {
+typedef struct SDL_HintWatch
+{
     SDL_HintCallback callback;
     void *userdata;
     struct SDL_HintWatch *next;
 } SDL_HintWatch;
 
-typedef struct SDL_Hint {
+typedef struct SDL_Hint
+{
     char *name;
     char *value;
     SDL_HintPriority priority;
@@ -44,9 +45,7 @@ typedef struct SDL_Hint {
 
 static SDL_Hint *SDL_hints;
 
-SDL_bool
-SDL_SetHintWithPriority(const char *name, const char *value,
-                        SDL_HintPriority priority)
+SDL_bool SDL_SetHintWithPriority(const char *name, const char *value, SDL_HintPriority priority)
 {
     const char *env;
     SDL_Hint *hint;
@@ -68,7 +67,7 @@ SDL_SetHintWithPriority(const char *name, const char *value,
             }
             if (hint->value != value &&
                 (!value || !hint->value || SDL_strcmp(hint->value, value) != 0)) {
-                for (entry = hint->callbacks; entry; ) {
+                for (entry = hint->callbacks; entry;) {
                     /* Save the next entry in case this one is deleted */
                     SDL_HintWatch *next = entry->next;
                     entry->callback(entry->userdata, name, hint->value, value);
@@ -96,8 +95,7 @@ SDL_SetHintWithPriority(const char *name, const char *value,
     return SDL_TRUE;
 }
 
-SDL_bool
-SDL_ResetHint(const char *name)
+SDL_bool SDL_ResetHint(const char *name)
 {
     const char *env;
     SDL_Hint *hint;
@@ -110,10 +108,10 @@ SDL_ResetHint(const char *name)
     env = SDL_getenv(name);
     for (hint = SDL_hints; hint; hint = hint->next) {
         if (SDL_strcmp(name, hint->name) == 0) {
-            if ((env == NULL && hint->value != NULL) ||
-                (env != NULL && hint->value == NULL) ||
-                (env != NULL && SDL_strcmp(env, hint->value) != 0)) {
-                for (entry = hint->callbacks; entry; ) {
+            if ((!env && hint->value) ||
+                (env && !hint->value) ||
+                (env && SDL_strcmp(env, hint->value) != 0)) {
+                for (entry = hint->callbacks; entry;) {
                     /* Save the next entry in case this one is deleted */
                     SDL_HintWatch *next = entry->next;
                     entry->callback(entry->userdata, name, hint->value, env);
@@ -129,8 +127,7 @@ SDL_ResetHint(const char *name)
     return SDL_FALSE;
 }
 
-void
-SDL_ResetHints(void)
+void SDL_ResetHints(void)
 {
     const char *env;
     SDL_Hint *hint;
@@ -138,10 +135,10 @@ SDL_ResetHints(void)
 
     for (hint = SDL_hints; hint; hint = hint->next) {
         env = SDL_getenv(hint->name);
-        if ((env == NULL && hint->value != NULL) ||
-            (env != NULL && hint->value == NULL) ||
-            (env != NULL && SDL_strcmp(env, hint->value) != 0)) {
-            for (entry = hint->callbacks; entry; ) {
+        if ((!env && hint->value) ||
+            (env && !hint->value) ||
+            (env && SDL_strcmp(env, hint->value) != 0)) {
+            for (entry = hint->callbacks; entry;) {
                 /* Save the next entry in case this one is deleted */
                 SDL_HintWatch *next = entry->next;
                 entry->callback(entry->userdata, hint->name, hint->value, env);
@@ -154,22 +151,24 @@ SDL_ResetHints(void)
     }
 }
 
-SDL_bool
-SDL_SetHint(const char *name, const char *value)
+SDL_bool SDL_SetHint(const char *name, const char *value)
 {
     return SDL_SetHintWithPriority(name, value, SDL_HINT_NORMAL);
 }
 
-const char *
-SDL_GetHint(const char *name)
+const char *SDL_GetHint(const char *name)
 {
     const char *env;
     SDL_Hint *hint;
 
+    if (!name) {
+        return NULL;
+    }
+
     env = SDL_getenv(name);
     for (hint = SDL_hints; hint; hint = hint->next) {
         if (SDL_strcmp(name, hint->name) == 0) {
-            if (env == NULL || hint->priority == SDL_HINT_OVERRIDE) {
+            if (!env || hint->priority == SDL_HINT_OVERRIDE) {
                 return hint->value;
             }
             break;
@@ -178,8 +177,7 @@ SDL_GetHint(const char *name)
     return env;
 }
 
-SDL_bool
-SDL_GetStringBoolean(const char *value, SDL_bool default_value)
+SDL_bool SDL_GetStringBoolean(const char *value, SDL_bool default_value)
 {
     if (!value || !*value) {
         return default_value;
@@ -190,15 +188,13 @@ SDL_GetStringBoolean(const char *value, SDL_bool default_value)
     return SDL_TRUE;
 }
 
-SDL_bool
-SDL_GetHintBoolean(const char *name, SDL_bool default_value)
+SDL_bool SDL_GetHintBoolean(const char *name, SDL_bool default_value)
 {
     const char *hint = SDL_GetHint(name);
     return SDL_GetStringBoolean(hint, default_value);
 }
 
-void
-SDL_AddHintCallback(const char *name, SDL_HintCallback callback, void *userdata)
+void SDL_AddHintCallback(const char *name, SDL_HintCallback callback, void *userdata)
 {
     SDL_Hint *hint;
     SDL_HintWatch *entry;
@@ -259,8 +255,7 @@ SDL_AddHintCallback(const char *name, SDL_HintCallback callback, void *userdata)
     callback(userdata, name, value, value);
 }
 
-void
-SDL_DelHintCallback(const char *name, SDL_HintCallback callback, void *userdata)
+void SDL_DelHintCallback(const char *name, SDL_HintCallback callback, void *userdata)
 {
     SDL_Hint *hint;
     SDL_HintWatch *entry, *prev;
@@ -296,7 +291,7 @@ void SDL_ClearHints(void)
 
         SDL_free(hint->name);
         SDL_free(hint->value);
-        for (entry = hint->callbacks; entry; ) {
+        for (entry = hint->callbacks; entry;) {
             SDL_HintWatch *freeable = entry;
             entry = entry->next;
             SDL_free(freeable);
