@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,6 +20,8 @@
 */
 #include "../../SDL_internal.h"
 
+#ifdef SDL_AUDIO_DRIVER_DUMMY
+
 /* Output audio to nowhere... */
 
 #include "SDL_timer.h"
@@ -27,15 +29,14 @@
 #include "../SDL_audio_c.h"
 #include "SDL_dummyaudio.h"
 
-static int
-DUMMYAUDIO_OpenDevice(_THIS, const char *devname)
+static int DUMMYAUDIO_OpenDevice(_THIS, const char *devname)
 {
-    _this->hidden = (void *) 0x1;  /* just something non-NULL */
-    return 0;                   /* always succeeds. */
+    _this->hidden = (void *)0x1; /* just something non-NULL */
+
+    return 0; /* always succeeds. */
 }
 
-static int
-DUMMYAUDIO_CaptureFromDevice(_THIS, void *buffer, int buflen)
+static int DUMMYAUDIO_CaptureFromDevice(_THIS, void *buffer, int buflen)
 {
     /* Delay to make this sort of simulate real audio input. */
     SDL_Delay((_this->spec.samples * 1000) / _this->spec.freq);
@@ -45,8 +46,7 @@ DUMMYAUDIO_CaptureFromDevice(_THIS, void *buffer, int buflen)
     return buflen;
 }
 
-static SDL_bool
-DUMMYAUDIO_Init(SDL_AudioDriverImpl * impl)
+static SDL_bool DUMMYAUDIO_Init(SDL_AudioDriverImpl *impl)
 {
     /* Set the function pointers */
     impl->OpenDevice = DUMMYAUDIO_OpenDevice;
@@ -56,11 +56,13 @@ DUMMYAUDIO_Init(SDL_AudioDriverImpl * impl)
     impl->OnlyHasDefaultCaptureDevice = SDL_TRUE;
     impl->HasCaptureSupport = SDL_TRUE;
 
-    return SDL_TRUE;   /* this audio target is available. */
+    return SDL_TRUE; /* this audio target is available. */
 }
 
 AudioBootStrap DUMMYAUDIO_bootstrap = {
     "dummy", "SDL dummy audio driver", DUMMYAUDIO_Init, SDL_TRUE
 };
 
+#endif
+
 /* vi: set ts=4 sw=4 expandtab: */
