@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_AUDIO_DRIVER_JACK
+#ifdef SDL_AUDIO_DRIVER_JACK
 
 #include "SDL_timer.h"
 #include "SDL_audio.h"
@@ -29,39 +29,36 @@
 #include "SDL_loadso.h"
 #include "../../thread/SDL_systhread.h"
 
-
-static jack_client_t * (*JACK_jack_client_open) (const char *, jack_options_t, jack_status_t *, ...);
-static int (*JACK_jack_client_close) (jack_client_t *);
-static void (*JACK_jack_on_shutdown) (jack_client_t *, JackShutdownCallback, void *);
-static int (*JACK_jack_activate) (jack_client_t *);
-static int (*JACK_jack_deactivate) (jack_client_t *);
-static void * (*JACK_jack_port_get_buffer) (jack_port_t *, jack_nframes_t);
-static int (*JACK_jack_port_unregister) (jack_client_t *, jack_port_t *);
-static void (*JACK_jack_free) (void *);
-static const char ** (*JACK_jack_get_ports) (jack_client_t *, const char *, const char *, unsigned long);
-static jack_nframes_t (*JACK_jack_get_sample_rate) (jack_client_t *);
-static jack_nframes_t (*JACK_jack_get_buffer_size) (jack_client_t *);
-static jack_port_t * (*JACK_jack_port_register) (jack_client_t *, const char *, const char *, unsigned long, unsigned long);
-static jack_port_t * (*JACK_jack_port_by_name) (jack_client_t *, const char *);
-static const char * (*JACK_jack_port_name) (const jack_port_t *);
-static const char * (*JACK_jack_port_type) (const jack_port_t *);
-static int (*JACK_jack_connect) (jack_client_t *, const char *, const char *);
-static int (*JACK_jack_set_process_callback) (jack_client_t *, JackProcessCallback, void *);
+static jack_client_t *(*JACK_jack_client_open)(const char *, jack_options_t, jack_status_t *, ...);
+static int (*JACK_jack_client_close)(jack_client_t *);
+static void (*JACK_jack_on_shutdown)(jack_client_t *, JackShutdownCallback, void *);
+static int (*JACK_jack_activate)(jack_client_t *);
+static int (*JACK_jack_deactivate)(jack_client_t *);
+static void *(*JACK_jack_port_get_buffer)(jack_port_t *, jack_nframes_t);
+static int (*JACK_jack_port_unregister)(jack_client_t *, jack_port_t *);
+static void (*JACK_jack_free)(void *);
+static const char **(*JACK_jack_get_ports)(jack_client_t *, const char *, const char *, unsigned long);
+static jack_nframes_t (*JACK_jack_get_sample_rate)(jack_client_t *);
+static jack_nframes_t (*JACK_jack_get_buffer_size)(jack_client_t *);
+static jack_port_t *(*JACK_jack_port_register)(jack_client_t *, const char *, const char *, unsigned long, unsigned long);
+static jack_port_t *(*JACK_jack_port_by_name)(jack_client_t *, const char *);
+static const char *(*JACK_jack_port_name)(const jack_port_t *);
+static const char *(*JACK_jack_port_type)(const jack_port_t *);
+static int (*JACK_jack_connect)(jack_client_t *, const char *, const char *);
+static int (*JACK_jack_set_process_callback)(jack_client_t *, JackProcessCallback, void *);
 
 static int load_jack_syms(void);
 
-
 #ifdef SDL_AUDIO_DRIVER_JACK_DYNAMIC
 
 static const char *jack_library = SDL_AUDIO_DRIVER_JACK_DYNAMIC;
 static void *jack_handle = NULL;
 
 /* !!! FIXME: this is copy/pasted in several places now */
-static int
-load_jack_sym(const char *fn, void **addr)
+static int load_jack_sym(const char *fn, void **addr)
 {
     *addr = SDL_LoadFunction(jack_handle, fn);
-    if (*addr == NULL) {
+    if (!*addr) {
         /* Don't call SDL_SetError(): SDL_LoadFunction already did. */
         return 0;
     }
@@ -70,25 +67,24 @@ load_jack_sym(const char *fn, void **addr)
 }
 
 /* cast funcs to char* first, to please GCC's strict aliasing rules. */
-#define SDL_JACK_SYM(x) \
-    if (!load_jack_sym(#x, (void **) (char *) &JACK_##x)) return -1
+#define SDL_JACK_SYM(x)                                 \
+    if (!load_jack_sym(#x, (void **)(char *)&JACK_##x)) \
+    return -1
 
-static void
-UnloadJackLibrary(void)
+static void UnloadJackLibrary(void)
 {
-    if (jack_handle != NULL) {
+    if (jack_handle) {
         SDL_UnloadObject(jack_handle);
         jack_handle = NULL;
     }
 }
 
-static int
-LoadJackLibrary(void)
+static int LoadJackLibrary(void)
 {
     int retval = 0;
-    if (jack_handle == NULL) {
+    if (!jack_handle) {
         jack_handle = SDL_LoadObject(jack_library);
-        if (jack_handle == NULL) {
+        if (!jack_handle) {
             retval = -1;
             /* Don't call SDL_SetError(): SDL_LoadObject already did. */
         } else {
@@ -105,13 +101,11 @@ LoadJackLibrary(void)
 
 #define SDL_JACK_SYM(x) JACK_##x = x
 
-static void
-UnloadJackLibrary(void)
+static void UnloadJackLibrary(void)
 {
 }
 
-static int
-LoadJackLibrary(void)
+static int LoadJackLibrary(void)
 {
     load_jack_syms();
     return 0;
@@ -119,9 +113,7 @@ LoadJackLibrary(void)
 
 #endif /* SDL_AUDIO_DRIVER_JACK_DYNAMIC */
 
-
-static int
-load_jack_syms(void)
+static int load_jack_syms(void)
 {
     SDL_JACK_SYM(jack_client_open);
     SDL_JACK_SYM(jack_client_close);
@@ -140,26 +132,24 @@ load_jack_syms(void)
     SDL_JACK_SYM(jack_port_type);
     SDL_JACK_SYM(jack_connect);
     SDL_JACK_SYM(jack_set_process_callback);
+
     return 0;
 }
 
-
-static void
-jackShutdownCallback(void *arg)  /* JACK went away; device is lost. */
+static void jackShutdownCallback(void *arg) /* JACK went away; device is lost. */
 {
-    SDL_AudioDevice *this = (SDL_AudioDevice *) arg;
+    SDL_AudioDevice *this = (SDL_AudioDevice *)arg;
     SDL_OpenedAudioDeviceDisconnected(this);
-    SDL_SemPost(this->hidden->iosem);  /* unblock the SDL thread. */
+    SDL_SemPost(this->hidden->iosem); /* unblock the SDL thread. */
 }
 
 // !!! FIXME: implement and register these!
-//typedef int(* JackSampleRateCallback)(jack_nframes_t nframes, void *arg)
-//typedef int(* JackBufferSizeCallback)(jack_nframes_t nframes, void *arg)
+// typedef int(* JackSampleRateCallback)(jack_nframes_t nframes, void *arg)
+// typedef int(* JackBufferSizeCallback)(jack_nframes_t nframes, void *arg)
 
-static int
-jackProcessPlaybackCallback(jack_nframes_t nframes, void *arg)
+static int jackProcessPlaybackCallback(jack_nframes_t nframes, void *arg)
 {
-    SDL_AudioDevice *this = (SDL_AudioDevice *) arg;
+    SDL_AudioDevice *this = (SDL_AudioDevice *)arg;
     jack_port_t **ports = this->hidden->sdlports;
     const int total_channels = this->spec.channels;
     const int total_frames = this->spec.samples;
@@ -171,9 +161,9 @@ jackProcessPlaybackCallback(jack_nframes_t nframes, void *arg)
     }
 
     for (channelsi = 0; channelsi < total_channels; channelsi++) {
-        float *dst = (float *) JACK_jack_port_get_buffer(ports[channelsi], nframes);
+        float *dst = (float *)JACK_jack_port_get_buffer(ports[channelsi], nframes);
         if (dst) {
-            const float *src = ((float *) this->hidden->iobuffer) + channelsi;
+            const float *src = this->hidden->iobuffer + channelsi;
             int framesi;
             for (framesi = 0; framesi < total_frames; framesi++) {
                 *(dst++) = *src;
@@ -182,14 +172,12 @@ jackProcessPlaybackCallback(jack_nframes_t nframes, void *arg)
         }
     }
 
-    SDL_SemPost(this->hidden->iosem);  /* tell SDL thread we're done; refill the buffer. */
-    return 0;  /* success */
+    SDL_SemPost(this->hidden->iosem); /* tell SDL thread we're done; refill the buffer. */
+    return 0;
 }
 
-
 /* This function waits until it is possible to write a full sound buffer */
-static void
-JACK_WaitDevice(_THIS)
+static void JACK_WaitDevice(_THIS)
 {
     if (SDL_AtomicGet(&this->enabled)) {
         if (SDL_SemWait(this->hidden->iosem) == -1) {
@@ -198,27 +186,24 @@ JACK_WaitDevice(_THIS)
     }
 }
 
-static Uint8 *
-JACK_GetDeviceBuf(_THIS)
+static Uint8 *JACK_GetDeviceBuf(_THIS)
 {
-    return (Uint8 *) this->hidden->iobuffer;
+    return (Uint8 *)this->hidden->iobuffer;
 }
 
-
-static int
-jackProcessCaptureCallback(jack_nframes_t nframes, void *arg)
+static int jackProcessCaptureCallback(jack_nframes_t nframes, void *arg)
 {
-    SDL_AudioDevice *this = (SDL_AudioDevice *) arg;
+    SDL_AudioDevice *this = (SDL_AudioDevice *)arg;
     if (SDL_AtomicGet(&this->enabled)) {
         jack_port_t **ports = this->hidden->sdlports;
         const int total_channels = this->spec.channels;
         const int total_frames = this->spec.samples;
         int channelsi;
-    
+
         for (channelsi = 0; channelsi < total_channels; channelsi++) {
-            const float *src = (const float *) JACK_jack_port_get_buffer(ports[channelsi], nframes);
+            const float *src = (const float *)JACK_jack_port_get_buffer(ports[channelsi], nframes);
             if (src) {
-                float *dst = ((float *) this->hidden->iobuffer) + channelsi;
+                float *dst = this->hidden->iobuffer + channelsi;
                 int framesi;
                 for (framesi = 0; framesi < total_frames; framesi++) {
                     *dst = *(src++);
@@ -228,14 +213,13 @@ jackProcessCaptureCallback(jack_nframes_t nframes, void *arg)
         }
     }
 
-    SDL_SemPost(this->hidden->iosem);  /* tell SDL thread we're done; new buffer is ready! */
-    return 0;  /* success */
+    SDL_SemPost(this->hidden->iosem); /* tell SDL thread we're done; new buffer is ready! */
+    return 0;
 }
 
-static int
-JACK_CaptureFromDevice(_THIS, void *buffer, int buflen)
+static int JACK_CaptureFromDevice(_THIS, void *buffer, int buflen)
 {
-    SDL_assert(buflen == this->spec.size);  /* we always fill a full buffer. */
+    SDL_assert(buflen == this->spec.size); /* we always fill a full buffer. */
 
     /* Wait for JACK to fill the iobuffer */
     if (SDL_SemWait(this->hidden->iosem) == -1) {
@@ -246,15 +230,12 @@ JACK_CaptureFromDevice(_THIS, void *buffer, int buflen)
     return buflen;
 }
 
-static void
-JACK_FlushCapture(_THIS)
+static void JACK_FlushCapture(_THIS)
 {
     SDL_SemWait(this->hidden->iosem);
 }
 
-
-static void
-JACK_CloseDevice(_THIS)
+static void JACK_CloseDevice(_THIS)
 {
     if (this->hidden->client) {
         JACK_jack_deactivate(this->hidden->client);
@@ -279,8 +260,7 @@ JACK_CloseDevice(_THIS)
     SDL_free(this->hidden);
 }
 
-static int
-JACK_OpenDevice(_THIS, const char *devname)
+static int JACK_OpenDevice(_THIS, const char *devname)
 {
     /* Note that JACK uses "output" for capture devices (they output audio
         data to us) and "input" for playback (we input audio data to them).
@@ -300,7 +280,7 @@ JACK_OpenDevice(_THIS, const char *devname)
     int i;
 
     /* Initialize all variables that we clean on shutdown */
-    this->hidden = (struct SDL_PrivateAudioData *) SDL_calloc(1, sizeof (*this->hidden));
+    this->hidden = (struct SDL_PrivateAudioData *)SDL_calloc(1, sizeof(*this->hidden));
     if (this->hidden == NULL) {
         return SDL_OutOfMemory();
     }
@@ -313,7 +293,7 @@ JACK_OpenDevice(_THIS, const char *devname)
     }
 
     devports = JACK_jack_get_ports(client, NULL, NULL, JackPortIsPhysical | sysportflags);
-    if (!devports || !devports[0]) {
+    if (devports == NULL || !devports[0]) {
         return SDL_SetError("No physical JACK ports available");
     }
 
@@ -322,21 +302,21 @@ JACK_OpenDevice(_THIS, const char *devname)
     }
 
     /* Filter out non-audio ports */
-    audio_ports = SDL_calloc(ports, sizeof *audio_ports);
+    audio_ports = SDL_calloc(ports, sizeof(*audio_ports));
     for (i = 0; i < ports; i++) {
         const jack_port_t *dport = JACK_jack_port_by_name(client, devports[i]);
         const char *type = JACK_jack_port_type(dport);
         const int len = SDL_strlen(type);
         /* See if type ends with "audio" */
-        if (len >= 5 && !SDL_memcmp(type+len-5, "audio", 5)) {
+        if (len >= 5 && !SDL_memcmp(type + len - 5, "audio", 5)) {
             audio_ports[channels++] = i;
         }
     }
     if (channels == 0) {
+        SDL_free(audio_ports);
         return SDL_SetError("No physical JACK ports available");
     }
 
-
     /* !!! FIXME: docs say about buffer size: "This size may change, clients that depend on it must register a bufsize_callback so they will be notified if it does." */
 
     /* Jack pretty much demands what it wants. */
@@ -349,36 +329,42 @@ JACK_OpenDevice(_THIS, const char *devname)
 
     this->hidden->iosem = SDL_CreateSemaphore(0);
     if (!this->hidden->iosem) {
-        return -1;  /* error was set by SDL_CreateSemaphore */
+        SDL_free(audio_ports);
+        return -1; /* error was set by SDL_CreateSemaphore */
     }
 
-    this->hidden->iobuffer = (float *) SDL_calloc(1, this->spec.size);
+    this->hidden->iobuffer = (float *)SDL_calloc(1, this->spec.size);
     if (!this->hidden->iobuffer) {
+        SDL_free(audio_ports);
         return SDL_OutOfMemory();
     }
 
     /* Build SDL's ports, which we will connect to the device ports. */
-    this->hidden->sdlports = (jack_port_t **) SDL_calloc(channels, sizeof (jack_port_t *));
-    if (this->hidden->sdlports == NULL) {
+    this->hidden->sdlports = (jack_port_t **)SDL_calloc(channels, sizeof(jack_port_t *));
+    if (!this->hidden->sdlports) {
+        SDL_free(audio_ports);
         return SDL_OutOfMemory();
     }
 
     for (i = 0; i < channels; i++) {
         char portname[32];
-        SDL_snprintf(portname, sizeof (portname), "sdl_jack_%s_%d", sdlportstr, i);
+        (void)SDL_snprintf(portname, sizeof(portname), "sdl_jack_%s_%d", sdlportstr, i);
         this->hidden->sdlports[i] = JACK_jack_port_register(client, portname, JACK_DEFAULT_AUDIO_TYPE, sdlportflags, 0);
         if (this->hidden->sdlports[i] == NULL) {
+            SDL_free(audio_ports);
             return SDL_SetError("jack_port_register failed");
         }
     }
 
     if (JACK_jack_set_process_callback(client, callback, this) != 0) {
+        SDL_free(audio_ports);
         return SDL_SetError("JACK: Couldn't set process callback");
     }
 
     JACK_jack_on_shutdown(client, jackShutdownCallback, this);
 
     if (JACK_jack_activate(client) != 0) {
+        SDL_free(audio_ports);
         return SDL_SetError("Failed to activate JACK client");
     }
 
@@ -388,6 +374,7 @@ JACK_OpenDevice(_THIS, const char *devname)
         const char *srcport = iscapture ? devports[audio_ports[i]] : sdlport;
         const char *dstport = iscapture ? sdlport : devports[audio_ports[i]];
         if (JACK_jack_connect(client, srcport, dstport) != 0) {
+            SDL_free(audio_ports);
             return SDL_SetError("Couldn't connect JACK ports: %s => %s", srcport, dstport);
         }
     }
@@ -400,14 +387,12 @@ JACK_OpenDevice(_THIS, const char *devname)
     return 0;
 }
 
-static void
-JACK_Deinitialize(void)
+static void JACK_Deinitialize(void)
 {
     UnloadJackLibrary();
 }
 
-static SDL_bool
-JACK_Init(SDL_AudioDriverImpl * impl)
+static SDL_bool JACK_Init(SDL_AudioDriverImpl *impl)
 {
     if (LoadJackLibrary() < 0) {
         return SDL_FALSE;
@@ -415,7 +400,7 @@ JACK_Init(SDL_AudioDriverImpl * impl)
         /* Make sure a JACK server is running and available. */
         jack_status_t status;
         jack_client_t *client = JACK_jack_client_open("SDL", JackNoStartServer, &status, NULL);
-        if (client == NULL) {
+        if (!client) {
             UnloadJackLibrary();
             return SDL_FALSE;
         }
@@ -434,7 +419,7 @@ JACK_Init(SDL_AudioDriverImpl * impl)
     impl->OnlyHasDefaultCaptureDevice = SDL_TRUE;
     impl->HasCaptureSupport = SDL_TRUE;
 
-    return SDL_TRUE;   /* this audio target is available. */
+    return SDL_TRUE; /* this audio target is available. */
 }
 
 AudioBootStrap JACK_bootstrap = {
