@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -18,6 +18,10 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 */
+
+#ifndef math_libm_h_
+#define math_libm_h_
+
 #include "../SDL_internal.h"
 
 /* Math routines from uClibc: http://www.uclibc.org */
@@ -26,6 +30,7 @@ double SDL_uclibc_atan(double x);
 double SDL_uclibc_atan2(double y, double x);    
 double SDL_uclibc_copysign(double x, double y);       
 double SDL_uclibc_cos(double x);         
+double SDL_uclibc_exp(double x);
 double SDL_uclibc_fabs(double x);        
 double SDL_uclibc_floor(double x);
 double SDL_uclibc_fmod(double x, double y);
@@ -37,4 +42,6 @@ double SDL_uclibc_sin(double x);
 double SDL_uclibc_sqrt(double x);
 double SDL_uclibc_tan(double x);
 
+#endif /* math_libm_h_ */
+
 /* vi: set ts=4 sw=4 expandtab: */
