@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -23,14 +23,23 @@
 
 #import <UIKit/UIKit.h>
 
-int
-SDL_SYS_OpenURL(const char *url)
-{ @autoreleasepool {
-
-    NSString *nsstr = [NSString stringWithUTF8String:url];
-    NSURL *nsurl = [NSURL URLWithString:nsstr];
-    return [[UIApplication sharedApplication] openURL:nsurl] ? 0 : -1;
-}}
+int SDL_SYS_OpenURL(const char *url)
+{
+    @autoreleasepool {
+        NSString *nsstr = [NSString stringWithUTF8String:url];
+        NSURL *nsurl = [NSURL URLWithString:nsstr];
+        if (![[UIApplication sharedApplication] canOpenURL:nsurl]) {
+            return SDL_SetError("No handler registered for this type of URL");
+        }
+        if (@available(iOS 10.0, tvOS 10.0, *)) {
+            [[UIApplication sharedApplication] openURL:nsurl options:@{} completionHandler:^(BOOL success) {}];
+        } else {
+            #ifndef SDL_PLATFORM_VISIONOS   /* Fallback is never available in any version of VisionOS (but correct API always is). */
+            [[UIApplication sharedApplication] openURL:nsurl];
+            #endif
+        }
+        return 0;
+    }
+}
 
 /* vi: set ts=4 sw=4 expandtab: */
-
