@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,8 +22,7 @@
 #include "../SDL_sysurl.h"
 #include "../../core/windows/SDL_windows.h"
 
-int
-SDL_SYS_OpenURL(const char *url)
+int SDL_SYS_OpenURL(const char *url)
 {
     WCHAR *wurl = WIN_UTF8ToStringW(url);
     if (!wurl) {
@@ -34,8 +33,7 @@ SDL_SYS_OpenURL(const char *url)
 
     auto uri = ref new Windows::Foundation::Uri(strurl);
     Windows::System::Launcher::LaunchUriAsync(uri);
-    return 0;  // oh well, we're not waiting on an async task here.
+    return 0; // oh well, we're not waiting on an async task here.
 }
 
 /* vi: set ts=4 sw=4 expandtab: */
-
