@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,12 +20,12 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_POWER_UIKIT
+#ifdef SDL_POWER_UIKIT
 
 #include "SDL_power.h"
 
 void SDL_UIKit_UpdateBatteryMonitoring(void);
-SDL_bool SDL_GetPowerInfo_UIKit(SDL_PowerState * state, int *seconds, int *percent);
+SDL_bool SDL_GetPowerInfo_UIKit(SDL_PowerState *state, int *seconds, int *percent);
 
 #endif /* SDL_POWER_UIKIT */
 
