@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -21,24 +21,22 @@
 #include "../../SDL_internal.h"
 
 #ifndef SDL_POWER_DISABLED
-#if SDL_POWER_WINDOWS
+#ifdef SDL_POWER_WINDOWS
 
 #include "../../core/windows/SDL_windows.h"
 
 #include "SDL_power.h"
 
-SDL_bool
-SDL_GetPowerInfo_Windows(SDL_PowerState * state, int *seconds, int *percent)
+SDL_bool SDL_GetPowerInfo_Windows(SDL_PowerState *state, int *seconds, int *percent)
 {
     SYSTEM_POWER_STATUS status;
     SDL_bool need_details = SDL_FALSE;
 
     /* This API should exist back to Win95. */
-    if (!GetSystemPowerStatus(&status))
-    {
+    if (!GetSystemPowerStatus(&status)) {
         /* !!! FIXME: push GetLastError() into SDL_GetError() */
         *state = SDL_POWERSTATE_UNKNOWN;
-    } else if (status.BatteryFlag == 0xFF) {    /* unknown state */
+    } else if (status.BatteryFlag == 0xFF) { /* unknown state */
         *state = SDL_POWERSTATE_UNKNOWN;
     } else if (status.BatteryFlag & (1 << 7)) { /* no battery */
         *state = SDL_POWERSTATE_NO_BATTERY;
@@ -46,28 +44,28 @@ SDL_GetPowerInfo_Windows(SDL_PowerState * state, int *seconds, int *percent)
         *state = SDL_POWERSTATE_CHARGING;
         need_details = SDL_TRUE;
     } else if (status.ACLineStatus == 1) {
-        *state = SDL_POWERSTATE_CHARGED;        /* on AC, not charging. */
+        *state = SDL_POWERSTATE_CHARGED; /* on AC, not charging. */
         need_details = SDL_TRUE;
     } else {
-        *state = SDL_POWERSTATE_ON_BATTERY;     /* not on AC. */
+        *state = SDL_POWERSTATE_ON_BATTERY; /* not on AC. */
         need_details = SDL_TRUE;
     }
 
     *percent = -1;
     *seconds = -1;
     if (need_details) {
-        const int pct = (int) status.BatteryLifePercent;
-        const int secs = (int) status.BatteryLifeTime;
+        const int pct = (int)status.BatteryLifePercent;
+        const int secs = (int)status.BatteryLifeTime;
 
-        if (pct != 255) {       /* 255 == unknown */
+        if (pct != 255) {                       /* 255 == unknown */
             *percent = (pct > 100) ? 100 : pct; /* clamp between 0%, 100% */
         }
-        if (secs != 0xFFFFFFFF) {       /* ((DWORD)-1) == unknown */
+        if (secs != 0xFFFFFFFF) { /* ((DWORD)-1) == unknown */
             *seconds = secs;
         }
     }
 
-    return SDL_TRUE;            /* always the definitive answer on Windows. */
+    return SDL_TRUE; /* always the definitive answer on Windows. */
 }
 
 #endif /* SDL_POWER_WINDOWS */
