@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_WINDOWS && !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
+#if defined(SDL_VIDEO_DRIVER_WINDOWS) && !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
 
 #include "SDL_windowsvideo.h"
 #include "../../events/SDL_displayevents_c.h"
@@ -33,23 +33,22 @@
 /* #define DEBUG_MODES */
 /* #define HIGHDPI_DEBUG_VERBOSE */
 
-static void
-WIN_UpdateDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode * mode)
+static void WIN_UpdateDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode *mode)
 {
-    SDL_DisplayModeData *data = (SDL_DisplayModeData *) mode->driverdata;
+    SDL_DisplayModeData *data = (SDL_DisplayModeData *)mode->driverdata;
     HDC hdc;
 
     data->DeviceMode.dmFields =
         (DM_BITSPERPEL | DM_PELSWIDTH | DM_PELSHEIGHT | DM_DISPLAYFREQUENCY |
          DM_DISPLAYFLAGS);
 
-    if (index == ENUM_CURRENT_SETTINGS
-        && (hdc = CreateDC(deviceName, NULL, NULL, NULL)) != NULL) {
+    /* NOLINTNEXTLINE(bugprone-assignment-in-if-condition): No simple way to extract the assignment */
+    if (index == ENUM_CURRENT_SETTINGS && (hdc = CreateDC(deviceName, NULL, NULL, NULL)) != NULL) {
         char bmi_data[sizeof(BITMAPINFOHEADER) + 256 * sizeof(RGBQUAD)];
         LPBITMAPINFO bmi;
         HBITMAP hbm;
-        int logical_width = GetDeviceCaps( hdc, HORZRES );
-        int logical_height = GetDeviceCaps( hdc, VERTRES );
+        int logical_width = GetDeviceCaps(hdc, HORZRES);
+        int logical_height = GetDeviceCaps(hdc, VERTRES);
 
         /* High-DPI notes:
 
@@ -62,9 +61,9 @@ WIN_UpdateDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode *
             - GetDeviceCaps( hdc, HORZRES ) will return pixels, same as DeviceMode.dmPelsWidth */
         mode->w = logical_width;
         mode->h = logical_height;
-        
+
         SDL_zeroa(bmi_data);
-        bmi = (LPBITMAPINFO) bmi_data;
+        bmi = (LPBITMAPINFO)bmi_data;
         bmi->bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
 
         hbm = CreateCompatibleBitmap(hdc, 1, 1);
@@ -73,7 +72,7 @@ WIN_UpdateDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode *
         DeleteObject(hbm);
         DeleteDC(hdc);
         if (bmi->bmiHeader.biCompression == BI_BITFIELDS) {
-            switch (*(Uint32 *) bmi->bmiColors) {
+            switch (*(Uint32 *)bmi->bmiColors) {
             case 0x00FF0000:
                 mode->format = SDL_PIXELFORMAT_RGB888;
                 break;
@@ -119,8 +118,7 @@ WIN_UpdateDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode *
     }
 }
 
-static SDL_DisplayOrientation
-WIN_GetDisplayOrientation(DEVMODE *mode)
+static SDL_DisplayOrientation WIN_GetDisplayOrientation(DEVMODE *mode)
 {
     int width = mode->dmPelsWidth;
     int height = mode->dmPelsHeight;
@@ -161,8 +159,7 @@ WIN_GetDisplayOrientation(DEVMODE *mode)
     }
 }
 
-static SDL_bool
-WIN_GetDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode * mode, SDL_DisplayOrientation *orientation)
+static SDL_bool WIN_GetDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode *mode, SDL_DisplayOrientation *orientation)
 {
     SDL_DisplayModeData *data;
     DEVMODE devmode;
@@ -173,7 +170,7 @@ WIN_GetDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode * mod
         return SDL_FALSE;
     }
 
-    data = (SDL_DisplayModeData *) SDL_malloc(sizeof(*data));
+    data = (SDL_DisplayModeData *)SDL_malloc(sizeof(*data));
     if (!data) {
         return SDL_FALSE;
     }
@@ -196,18 +193,8 @@ WIN_GetDisplayMode(_THIS, LPCWSTR deviceName, DWORD index, SDL_DisplayMode * mod
     return SDL_TRUE;
 }
 
-/* The win32 API calls in this function require Windows Vista or later. */
-typedef LONG (WINAPI *SDL_WIN32PROC_GetDisplayConfigBufferSizes)(UINT32 flags, UINT32* numPathArrayElements, UINT32* numModeInfoArrayElements);
-typedef LONG (WINAPI *SDL_WIN32PROC_QueryDisplayConfig)(UINT32 flags, UINT32* numPathArrayElements, DISPLAYCONFIG_PATH_INFO* pathArray, UINT32* numModeInfoArrayElements, DISPLAYCONFIG_MODE_INFO* modeInfoArray, DISPLAYCONFIG_TOPOLOGY_ID* currentTopologyId);
-typedef LONG (WINAPI *SDL_WIN32PROC_DisplayConfigGetDeviceInfo)(DISPLAYCONFIG_DEVICE_INFO_HEADER* requestPacket);
-
-static char *
-WIN_GetDisplayNameVista(const WCHAR *deviceName)
+static char *WIN_GetDisplayNameVista(SDL_VideoData *videodata, const WCHAR *deviceName)
 {
-    void *dll;
-    SDL_WIN32PROC_GetDisplayConfigBufferSizes pGetDisplayConfigBufferSizes;
-    SDL_WIN32PROC_QueryDisplayConfig pQueryDisplayConfig;
-    SDL_WIN32PROC_DisplayConfigGetDeviceInfo pDisplayConfigGetDeviceInfo;
     DISPLAYCONFIG_PATH_INFO *paths = NULL;
     DISPLAYCONFIG_MODE_INFO *modes = NULL;
     char *retval = NULL;
@@ -216,21 +203,12 @@ WIN_GetDisplayNameVista(const WCHAR *deviceName)
     UINT32 i;
     LONG rc;
 
-    dll = SDL_LoadObject("USER32.DLL");
-    if (!dll) {
+    if (!videodata->GetDisplayConfigBufferSizes || !videodata->QueryDisplayConfig || !videodata->DisplayConfigGetDeviceInfo) {
         return NULL;
     }
 
-    pGetDisplayConfigBufferSizes = (SDL_WIN32PROC_GetDisplayConfigBufferSizes) SDL_LoadFunction(dll, "GetDisplayConfigBufferSizes");
-    pQueryDisplayConfig = (SDL_WIN32PROC_QueryDisplayConfig) SDL_LoadFunction(dll, "QueryDisplayConfig");
-    pDisplayConfigGetDeviceInfo = (SDL_WIN32PROC_DisplayConfigGetDeviceInfo) SDL_LoadFunction(dll, "DisplayConfigGetDeviceInfo");
-
-    if (!pGetDisplayConfigBufferSizes || !pQueryDisplayConfig || !pDisplayConfigGetDeviceInfo) {
-        goto WIN_GetDisplayNameVista_failed;
-    }
-
     do {
-        rc = pGetDisplayConfigBufferSizes(QDC_ONLY_ACTIVE_PATHS, &pathCount, &modeCount);
+        rc = videodata->GetDisplayConfigBufferSizes(QDC_ONLY_ACTIVE_PATHS, &pathCount, &modeCount);
         if (rc != ERROR_SUCCESS) {
             goto WIN_GetDisplayNameVista_failed;
         }
@@ -238,13 +216,13 @@ WIN_GetDisplayNameVista(const WCHAR *deviceName)
         SDL_free(paths);
         SDL_free(modes);
 
-        paths = (DISPLAYCONFIG_PATH_INFO *) SDL_malloc(sizeof (DISPLAYCONFIG_PATH_INFO) * pathCount);
-        modes = (DISPLAYCONFIG_MODE_INFO *) SDL_malloc(sizeof (DISPLAYCONFIG_MODE_INFO) * modeCount);
-        if ((paths == NULL) || (modes == NULL)) {
+        paths = (DISPLAYCONFIG_PATH_INFO *)SDL_malloc(sizeof(DISPLAYCONFIG_PATH_INFO) * pathCount);
+        modes = (DISPLAYCONFIG_MODE_INFO *)SDL_malloc(sizeof(DISPLAYCONFIG_MODE_INFO) * modeCount);
+        if ((!paths) || (!modes)) {
             goto WIN_GetDisplayNameVista_failed;
         }
 
-        rc = pQueryDisplayConfig(QDC_ONLY_ACTIVE_PATHS, &pathCount, paths, &modeCount, modes, 0);
+        rc = videodata->QueryDisplayConfig(QDC_ONLY_ACTIVE_PATHS, &pathCount, paths, &modeCount, modes, 0);
     } while (rc == ERROR_INSUFFICIENT_BUFFER);
 
     if (rc == ERROR_SUCCESS) {
@@ -255,9 +233,9 @@ WIN_GetDisplayNameVista(const WCHAR *deviceName)
             SDL_zero(sourceName);
             sourceName.header.adapterId = paths[i].targetInfo.adapterId;
             sourceName.header.type = DISPLAYCONFIG_DEVICE_INFO_GET_SOURCE_NAME;
-            sourceName.header.size = sizeof (sourceName);
+            sourceName.header.size = sizeof(sourceName);
             sourceName.header.id = paths[i].sourceInfo.id;
-            rc = pDisplayConfigGetDeviceInfo(&sourceName.header);
+            rc = videodata->DisplayConfigGetDeviceInfo(&sourceName.header);
             if (rc != ERROR_SUCCESS) {
                 break;
             } else if (SDL_wcscmp(deviceName, sourceName.viewGdiDeviceName) != 0) {
@@ -268,8 +246,8 @@ WIN_GetDisplayNameVista(const WCHAR *deviceName)
             targetName.header.adapterId = paths[i].targetInfo.adapterId;
             targetName.header.id = paths[i].targetInfo.id;
             targetName.header.type = DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_NAME;
-            targetName.header.size = sizeof (targetName);
-            rc = pDisplayConfigGetDeviceInfo(&targetName.header);
+            targetName.header.size = sizeof(targetName);
+            rc = videodata->DisplayConfigGetDeviceInfo(&targetName.header);
             if (rc == ERROR_SUCCESS) {
                 retval = WIN_StringToUTF8W(targetName.monitorFriendlyDeviceName);
                 /* if we got an empty string, treat it as failure so we'll fallback
@@ -285,21 +263,18 @@ WIN_GetDisplayNameVista(const WCHAR *deviceName)
 
     SDL_free(paths);
     SDL_free(modes);
-    SDL_UnloadObject(dll);
     return retval;
 
 WIN_GetDisplayNameVista_failed:
     SDL_free(retval);
     SDL_free(paths);
     SDL_free(modes);
-    SDL_UnloadObject(dll);
     return NULL;
 }
 
-static SDL_bool
-WIN_AddDisplay(_THIS, HMONITOR hMonitor, const MONITORINFOEXW *info, SDL_bool send_event)
+static void WIN_AddDisplay(_THIS, HMONITOR hMonitor, const MONITORINFOEXW *info, int *display_index, SDL_bool send_event)
 {
-    int i;
+    int i, index = *display_index;
     SDL_VideoDisplay display;
     SDL_DisplayData *displaydata;
     SDL_DisplayMode mode;
@@ -310,42 +285,64 @@ WIN_AddDisplay(_THIS, HMONITOR hMonitor, const MONITORINFOEXW *info, SDL_bool se
 #endif
 
     if (!WIN_GetDisplayMode(_this, info->szDevice, ENUM_CURRENT_SETTINGS, &mode, &orientation)) {
-        return SDL_FALSE;
+        return;
     }
 
     // Prevent adding duplicate displays. Do this after we know the display is
     // ready to be added to allow any displays that we can't fully query to be
     // removed
-    for(i = 0; i < _this->num_displays; ++i) {
+    for (i = 0; i < _this->num_displays; ++i) {
         SDL_DisplayData *driverdata = (SDL_DisplayData *)_this->displays[i].driverdata;
         if (SDL_wcscmp(driverdata->DeviceName, info->szDevice) == 0) {
+            SDL_bool moved = (index != i);
+
+            if (index >= _this->num_displays) {
+                return;
+            }
+
+            if (moved) {
+                SDL_VideoDisplay tmp;
+
+                SDL_memcpy(&tmp, &_this->displays[index], sizeof(tmp));
+                SDL_memcpy(&_this->displays[index], &_this->displays[i], sizeof(tmp));
+                SDL_memcpy(&_this->displays[i], &tmp, sizeof(tmp));
+                i = index;
+            }
+
             driverdata->MonitorHandle = hMonitor;
             driverdata->IsValid = SDL_TRUE;
 
             if (!_this->setting_display_mode) {
+                SDL_Rect bounds;
+
                 SDL_ResetDisplayModes(i);
                 SDL_SetCurrentDisplayMode(&_this->displays[i], &mode);
                 SDL_SetDesktopDisplayMode(&_this->displays[i], &mode);
+                if (WIN_GetDisplayBounds(_this, &_this->displays[i], &bounds) == 0) {
+                    if (SDL_memcmp(&driverdata->bounds, &bounds, sizeof(bounds)) != 0 || moved) {
+                        SDL_SendDisplayEvent(&_this->displays[i], SDL_DISPLAYEVENT_MOVED, 0);
+                    }
+                }
                 SDL_SendDisplayEvent(&_this->displays[i], SDL_DISPLAYEVENT_ORIENTATION, orientation);
             }
-            return SDL_FALSE;
+            goto done;
         }
     }
 
-    displaydata = (SDL_DisplayData *) SDL_calloc(1, sizeof(*displaydata));
+    displaydata = (SDL_DisplayData *)SDL_calloc(1, sizeof(*displaydata));
     if (!displaydata) {
-        return SDL_FALSE;
+        return;
     }
     SDL_memcpy(displaydata->DeviceName, info->szDevice, sizeof(displaydata->DeviceName));
     displaydata->MonitorHandle = hMonitor;
     displaydata->IsValid = SDL_TRUE;
 
     SDL_zero(display);
-    display.name = WIN_GetDisplayNameVista(info->szDevice);
-    if (display.name == NULL) {
+    display.name = WIN_GetDisplayNameVista(_this->driverdata, info->szDevice);
+    if (!display.name) {
         DISPLAY_DEVICEW device;
         SDL_zero(device);
-        device.cb = sizeof (device);
+        device.cb = sizeof(device);
         if (EnumDisplayDevicesW(info->szDevice, 0, &device, 0)) {
             display.name = WIN_StringToUTF8W(device.DeviceString);
         }
@@ -354,25 +351,30 @@ WIN_AddDisplay(_THIS, HMONITOR hMonitor, const MONITORINFOEXW *info, SDL_bool se
     display.desktop_mode = mode;
     display.current_mode = mode;
     display.orientation = orientation;
+    display.device = _this;
     display.driverdata = displaydata;
-    SDL_AddVideoDisplay(&display, send_event);
+    WIN_GetDisplayBounds(_this, &display, &displaydata->bounds);
+    index = SDL_AddVideoDisplay(&display, send_event);
     SDL_free(display.name);
-    return SDL_TRUE;
+
+done:
+    *display_index = index + 1;
 }
 
-typedef struct _WIN_AddDisplaysData {
+typedef struct _WIN_AddDisplaysData
+{
     SDL_VideoDevice *video_device;
+    int display_index;
     SDL_bool send_event;
     SDL_bool want_primary;
 } WIN_AddDisplaysData;
 
-static BOOL CALLBACK
-WIN_AddDisplaysCallback(HMONITOR hMonitor,
-                        HDC      hdcMonitor,
-                        LPRECT   lprcMonitor,
-                        LPARAM   dwData)
+static BOOL CALLBACK WIN_AddDisplaysCallback(HMONITOR hMonitor,
+                                             HDC hdcMonitor,
+                                             LPRECT lprcMonitor,
+                                             LPARAM dwData)
 {
-    WIN_AddDisplaysData *data = (WIN_AddDisplaysData*)dwData;
+    WIN_AddDisplaysData *data = (WIN_AddDisplaysData *)dwData;
     MONITORINFOEXW info;
 
     SDL_zero(info);
@@ -382,7 +384,7 @@ WIN_AddDisplaysCallback(HMONITOR hMonitor,
         const SDL_bool is_primary = ((info.dwFlags & MONITORINFOF_PRIMARY) == MONITORINFOF_PRIMARY);
 
         if (is_primary == data->want_primary) {
-            WIN_AddDisplay(data->video_device, hMonitor, &info, data->send_event);
+            WIN_AddDisplay(data->video_device, hMonitor, &info, &data->display_index, data->send_event);
         }
     }
 
@@ -390,11 +392,11 @@ WIN_AddDisplaysCallback(HMONITOR hMonitor,
     return TRUE;
 }
 
-static void
-WIN_AddDisplays(_THIS, SDL_bool send_event)
+static void WIN_AddDisplays(_THIS, SDL_bool send_event)
 {
     WIN_AddDisplaysData callback_data;
     callback_data.video_device = _this;
+    callback_data.display_index = 0;
     callback_data.send_event = send_event;
 
     callback_data.want_primary = SDL_TRUE;
@@ -404,8 +406,7 @@ WIN_AddDisplays(_THIS, SDL_bool send_event)
     EnumDisplayMonitors(NULL, NULL, WIN_AddDisplaysCallback, (LPARAM)&callback_data);
 }
 
-int
-WIN_InitModes(_THIS)
+int WIN_InitModes(_THIS)
 {
     WIN_AddDisplays(_this, SDL_FALSE);
 
@@ -416,13 +417,12 @@ WIN_InitModes(_THIS)
 }
 
 /**
- * Convert the monitor rect and work rect from pixels to the SDL coordinate system (monitor origins are in pixels, 
+ * Convert the monitor rect and work rect from pixels to the SDL coordinate system (monitor origins are in pixels,
  * monitor size in DPI-scaled points).
- * 
+ *
  * No-op if DPI scaling is not enabled.
  */
-static void
-WIN_MonitorInfoToSDL(const SDL_VideoData *videodata, HMONITOR monitor, MONITORINFO *info)
+static void WIN_MonitorInfoToSDL(const SDL_VideoData *videodata, HMONITOR monitor, MONITORINFO *info)
 {
     UINT xdpi, ydpi;
 
@@ -444,14 +444,13 @@ WIN_MonitorInfoToSDL(const SDL_VideoData *videodata, HMONITOR monitor, MONITORIN
     info->rcMonitor.bottom = info->rcMonitor.top + MulDiv(info->rcMonitor.bottom - info->rcMonitor.top, 96, ydpi);
 
     /* Convert monitor work rect to points */
-    info->rcWork.left   = info->rcMonitor.left + MulDiv(info->rcWork.left - info->rcMonitor.left,  96, xdpi);
-    info->rcWork.right  = info->rcMonitor.left + MulDiv(info->rcWork.right - info->rcMonitor.left, 96, xdpi);
-    info->rcWork.top    = info->rcMonitor.top  + MulDiv(info->rcWork.top - info->rcMonitor.top,    96, ydpi);
-    info->rcWork.bottom = info->rcMonitor.top  + MulDiv(info->rcWork.bottom - info->rcMonitor.top, 96, ydpi);
+    info->rcWork.left = info->rcMonitor.left + MulDiv(info->rcWork.left - info->rcMonitor.left, 96, xdpi);
+    info->rcWork.right = info->rcMonitor.left + MulDiv(info->rcWork.right - info->rcMonitor.left, 96, xdpi);
+    info->rcWork.top = info->rcMonitor.top + MulDiv(info->rcWork.top - info->rcMonitor.top, 96, ydpi);
+    info->rcWork.bottom = info->rcMonitor.top + MulDiv(info->rcWork.bottom - info->rcMonitor.top, 96, ydpi);
 }
 
-int
-WIN_GetDisplayBounds(_THIS, SDL_VideoDisplay * display, SDL_Rect * rect)
+int WIN_GetDisplayBounds(_THIS, SDL_VideoDisplay *display, SDL_Rect *rect)
 {
     const SDL_DisplayData *data = (const SDL_DisplayData *)display->driverdata;
     const SDL_VideoData *videodata = (SDL_VideoData *)display->device->driverdata;
@@ -475,13 +474,12 @@ WIN_GetDisplayBounds(_THIS, SDL_VideoDisplay * display, SDL_Rect * rect)
     return 0;
 }
 
-int
-WIN_GetDisplayDPI(_THIS, SDL_VideoDisplay * display, float * ddpi_out, float * hdpi_out, float * vdpi_out)
+int WIN_GetDisplayDPI(_THIS, SDL_VideoDisplay *display, float *ddpi_out, float *hdpi_out, float *vdpi_out)
 {
     const SDL_DisplayData *displaydata = (SDL_DisplayData *)display->driverdata;
     const SDL_VideoData *videodata = (SDL_VideoData *)display->device->driverdata;
     float hdpi = 0, vdpi = 0, ddpi = 0;
-    
+
     if (videodata->GetDpiForMonitor) {
         UINT hdpi_uint, vdpi_uint;
         // Windows 8.1+ codepath
@@ -500,7 +498,7 @@ WIN_GetDisplayDPI(_THIS, SDL_VideoDisplay * display, float * ddpi_out, float * h
         float hinches, vinches;
 
         hdc = GetDC(NULL);
-        if (hdc == NULL) {
+        if (!hdc) {
             return SDL_SetError("GetDC failed");
         }
         hdpi_int = GetDeviceCaps(hdc, LOGPIXELSX);
@@ -534,8 +532,7 @@ WIN_GetDisplayDPI(_THIS, SDL_VideoDisplay * display, float * ddpi_out, float * h
     return ddpi != 0.0f ? 0 : SDL_SetError("Couldn't get DPI");
 }
 
-int
-WIN_GetDisplayUsableBounds(_THIS, SDL_VideoDisplay * display, SDL_Rect * rect)
+int WIN_GetDisplayUsableBounds(_THIS, SDL_VideoDisplay *display, SDL_Rect *rect)
 {
     const SDL_DisplayData *data = (const SDL_DisplayData *)display->driverdata;
     const SDL_VideoData *videodata = (SDL_VideoData *)display->device->driverdata;
@@ -560,11 +557,11 @@ WIN_GetDisplayUsableBounds(_THIS, SDL_VideoDisplay * display, SDL_Rect * rect)
 }
 
 /**
- * Convert a point from the SDL coordinate system (monitor origins are in pixels, 
+ * Convert a point from the SDL coordinate system (monitor origins are in pixels,
  * offset within a monitor in DPI-scaled points) to Windows virtual screen coordinates (pixels).
- * 
+ *
  * No-op if DPI scaling is not enabled (returns 96 dpi).
- * 
+ *
  * Returns the DPI of the monitor that was closest to x, y and used for the conversion.
  */
 void WIN_ScreenPointFromSDL(int *x, int *y, int *dpiOut)
@@ -576,8 +573,8 @@ void WIN_ScreenPointFromSDL(int *x, int *y, int *dpiOut)
     float ddpi, hdpi, vdpi;
     int x_sdl, y_sdl;
     SDL_Point point;
-	point.x = *x;
-	point.y = *y;
+    point.x = *x;
+    point.y = *y;
 
     if (dpiOut) {
         *dpiOut = 96;
@@ -599,13 +596,12 @@ void WIN_ScreenPointFromSDL(int *x, int *y, int *dpiOut)
         return;
     }
 
-    if (SDL_GetDisplayBounds(displayIndex, &bounds) < 0
-        || SDL_GetDisplayDPI(displayIndex, &ddpi, &hdpi, &vdpi) < 0) {
+    if (SDL_GetDisplayBounds(displayIndex, &bounds) < 0 || SDL_GetDisplayDPI(displayIndex, &ddpi, &hdpi, &vdpi) < 0) {
         return;
     }
 
     if (dpiOut) {
-        *dpiOut = (int) ddpi;
+        *dpiOut = (int)ddpi;
     }
 
     /* Undo the DPI-scaling within the monitor bounds to convert back to pixels */
@@ -616,7 +612,7 @@ void WIN_ScreenPointFromSDL(int *x, int *y, int *dpiOut)
 
 #ifdef HIGHDPI_DEBUG_VERBOSE
     SDL_Log("WIN_ScreenPointFromSDL: (%d, %d) points -> (%d x %d) pixels, using %d DPI monitor",
-        x_sdl, y_sdl, *x, *y, (int)ddpi);
+            x_sdl, y_sdl, *x, *y, (int)ddpi);
 #endif
 }
 
@@ -645,7 +641,7 @@ void WIN_ScreenPointToSDL(int *x, int *y)
     if (!videodata->dpi_scaling_enabled) {
         return;
     }
-    
+
     point.x = *x;
     point.y = *y;
     monitor = MonitorFromPoint(point, MONITOR_DEFAULTTONEAREST);
@@ -663,8 +659,7 @@ void WIN_ScreenPointToSDL(int *x, int *y)
     }
 
     /* Get SDL display properties */
-    if (SDL_GetDisplayBounds(displayIndex, &bounds) < 0
-        || SDL_GetDisplayDPI(displayIndex, &ddpi, &hdpi, &vdpi) < 0) {
+    if (SDL_GetDisplayBounds(displayIndex, &bounds) < 0 || SDL_GetDisplayDPI(displayIndex, &ddpi, &hdpi, &vdpi) < 0) {
         return;
     }
 
@@ -676,18 +671,17 @@ void WIN_ScreenPointToSDL(int *x, int *y)
 
 #ifdef HIGHDPI_DEBUG_VERBOSE
     SDL_Log("WIN_ScreenPointToSDL: (%d, %d) pixels -> (%d x %d) points, using %d DPI monitor",
-        x_pixels, y_pixels, *x, *y, (int)ddpi);
+            x_pixels, y_pixels, *x, *y, (int)ddpi);
 #endif
 }
 
-void
-WIN_GetDisplayModes(_THIS, SDL_VideoDisplay * display)
+void WIN_GetDisplayModes(_THIS, SDL_VideoDisplay *display)
 {
-    SDL_DisplayData *data = (SDL_DisplayData *) display->driverdata;
+    SDL_DisplayData *data = (SDL_DisplayData *)display->driverdata;
     DWORD i;
     SDL_DisplayMode mode;
 
-    for (i = 0; ; ++i) {
+    for (i = 0;; ++i) {
         if (!WIN_GetDisplayMode(_this, data->DeviceName, i, &mode, NULL)) {
             break;
         }
@@ -707,8 +701,7 @@ WIN_GetDisplayModes(_THIS, SDL_VideoDisplay * display)
 }
 
 #ifdef DEBUG_MODES
-static void
-WIN_LogMonitor(_THIS, HMONITOR mon)
+static void WIN_LogMonitor(_THIS, HMONITOR mon)
 {
     const SDL_VideoData *vid_data = (const SDL_VideoData *)_this->driverdata;
     MONITORINFOEX minfo;
@@ -726,22 +719,21 @@ WIN_LogMonitor(_THIS, HMONITOR mon)
     name_utf8 = WIN_StringToUTF8(minfo.szDevice);
 
     SDL_Log("WIN_LogMonitor: monitor \"%s\": dpi: %d windows screen coordinates: %d, %d, %dx%d",
-        name_utf8,
-        xdpi,
-        minfo.rcMonitor.left,
-        minfo.rcMonitor.top,
-        minfo.rcMonitor.right - minfo.rcMonitor.left,
-        minfo.rcMonitor.bottom - minfo.rcMonitor.top);
+            name_utf8,
+            xdpi,
+            minfo.rcMonitor.left,
+            minfo.rcMonitor.top,
+            minfo.rcMonitor.right - minfo.rcMonitor.left,
+            minfo.rcMonitor.bottom - minfo.rcMonitor.top);
 
     SDL_free(name_utf8);
 }
 #endif
 
-int
-WIN_SetDisplayMode(_THIS, SDL_VideoDisplay * display, SDL_DisplayMode * mode)
+int WIN_SetDisplayMode(_THIS, SDL_VideoDisplay *display, SDL_DisplayMode *mode)
 {
-    SDL_DisplayData *displaydata = (SDL_DisplayData *) display->driverdata;
-    SDL_DisplayModeData *data = (SDL_DisplayModeData *) mode->driverdata;
+    SDL_DisplayData *displaydata = (SDL_DisplayData *)display->driverdata;
+    SDL_DisplayModeData *data = (SDL_DisplayModeData *)mode->driverdata;
     LONG status;
 
 #ifdef DEBUG_MODES
@@ -799,8 +791,7 @@ WIN_SetDisplayMode(_THIS, SDL_VideoDisplay * display, SDL_DisplayMode * mode)
     return 0;
 }
 
-void
-WIN_RefreshDisplays(_THIS)
+void WIN_RefreshDisplays(_THIS)
 {
     int i;
 
@@ -825,8 +816,7 @@ WIN_RefreshDisplays(_THIS)
     }
 }
 
-void
-WIN_QuitModes(_THIS)
+void WIN_QuitModes(_THIS)
 {
     /* All fullscreen windows should have restored modes by now */
 }
