@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_WINRT
+#ifdef SDL_VIDEO_DRIVER_WINRT
 
 /*
  * Windows includes:
@@ -44,15 +44,12 @@ extern "C" {
 #include "../../events/SDL_events_c.h"
 }
 
-
 /* Forward declarations */
 static void WINRT_YieldXAMLThread();
 
-
 /* Global event management */
 
-void
-WINRT_PumpEvents(_THIS)
+void WINRT_PumpEvents(_THIS)
 {
     if (SDL_WinRTGlobalApp) {
         SDL_WinRTGlobalApp->PumpEvents();
@@ -61,7 +58,6 @@ WINRT_PumpEvents(_THIS)
     }
 }
 
-
 /* XAML Thread management */
 
 enum SDL_XAMLAppThreadState
@@ -72,12 +68,11 @@ enum SDL_XAMLAppThreadState
 };
 
 static SDL_XAMLAppThreadState _threadState = ThreadState_NotLaunched;
-static SDL_Thread * _XAMLThread = nullptr;
-static SDL_mutex * _mutex = nullptr;
-static SDL_cond * _cond = nullptr;
+static SDL_Thread *_XAMLThread = nullptr;
+static SDL_mutex *_mutex = nullptr;
+static SDL_cond *_cond = nullptr;
 
-static void
-WINRT_YieldXAMLThread()
+static void WINRT_YieldXAMLThread()
 {
     SDL_LockMutex(_mutex);
     SDL_assert(_threadState == ThreadState_Running);
@@ -93,8 +88,7 @@ WINRT_YieldXAMLThread()
     SDL_UnlockMutex(_mutex);
 }
 
-static int
-WINRT_XAMLThreadMain(void * userdata)
+static int WINRT_XAMLThreadMain(void *userdata)
 {
     // TODO, WinRT: pass the C-style main() a reasonably realistic
     // representation of command line arguments.
@@ -103,48 +97,47 @@ WINRT_XAMLThreadMain(void * userdata)
     return WINRT_SDLAppEntryPoint(argc, argv);
 }
 
-void
-WINRT_CycleXAMLThread(void)
+void WINRT_CycleXAMLThread(void)
 {
     switch (_threadState) {
-        case ThreadState_NotLaunched:
-        {
-            _cond = SDL_CreateCond();
+    case ThreadState_NotLaunched:
+    {
+        _cond = SDL_CreateCond();
 
-            _mutex = SDL_CreateMutex();
-            _threadState = ThreadState_Running;
-            _XAMLThread = SDL_CreateThreadInternal(WINRT_XAMLThreadMain, "SDL/XAML App Thread", 0, nullptr);
+        _mutex = SDL_CreateMutex();
+        _threadState = ThreadState_Running;
+        _XAMLThread = SDL_CreateThreadInternal(WINRT_XAMLThreadMain, "SDL/XAML App Thread", 0, nullptr);
 
-            SDL_LockMutex(_mutex);
-            while (_threadState != ThreadState_Yielding) {
-                SDL_CondWait(_cond, _mutex);
-            }
-            SDL_UnlockMutex(_mutex);
-
-            break;
+        SDL_LockMutex(_mutex);
+        while (_threadState != ThreadState_Yielding) {
+            SDL_CondWait(_cond, _mutex);
         }
+        SDL_UnlockMutex(_mutex);
 
-        case ThreadState_Running:
-        {
-            SDL_assert(false);
-            break;
-        }
+        break;
+    }
 
-        case ThreadState_Yielding:
-        {
-            SDL_LockMutex(_mutex);
-            SDL_assert(_threadState == ThreadState_Yielding);
-            _threadState = ThreadState_Running;
-            SDL_UnlockMutex(_mutex);
+    case ThreadState_Running:
+    {
+        SDL_assert(false);
+        break;
+    }
 
-            SDL_CondSignal(_cond);
+    case ThreadState_Yielding:
+    {
+        SDL_LockMutex(_mutex);
+        SDL_assert(_threadState == ThreadState_Yielding);
+        _threadState = ThreadState_Running;
+        SDL_UnlockMutex(_mutex);
 
-            SDL_LockMutex(_mutex);
-            while (_threadState != ThreadState_Yielding) {
-                SDL_CondWait(_cond, _mutex);
-            }
-            SDL_UnlockMutex(_mutex);
+        SDL_CondSignal(_cond);
+
+        SDL_LockMutex(_mutex);
+        while (_threadState != ThreadState_Yielding) {
+            SDL_CondWait(_cond, _mutex);
         }
+        SDL_UnlockMutex(_mutex);
+    }
     }
 }
 
