@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_WINRT
+#ifdef SDL_VIDEO_DRIVER_WINRT
 
 /* WinRT SDL video driver implementation
 
@@ -29,10 +29,8 @@
  */
 
 /* Standard C++11 includes */
-#include <functional>
-#include <string>
 #include <sstream>
-using namespace std;
+#include <string>
 
 /* Windows includes */
 #include <agile.h>
@@ -46,11 +44,9 @@ using namespace Windows::Graphics::Display;
 using namespace Windows::UI::Core;
 using namespace Windows::UI::ViewManagement;
 
-
 /* [re]declare Windows GUIDs locally, to limit the amount of external lib(s) SDL has to link to */
-static const GUID SDL_IID_IDisplayRequest   = { 0xe5732044, 0xf49f, 0x4b60, { 0x8d, 0xd4, 0x5e, 0x7e, 0x3a, 0x63, 0x2a, 0xc0 } };
-static const GUID SDL_IID_IDXGIFactory2     = { 0x50c83a1c, 0xe072, 0x4c48, { 0x87, 0xb0, 0x36, 0x30, 0xfa, 0x36, 0xa6, 0xd0 } };
-
+static const GUID SDL_IID_IDisplayRequest = { 0xe5732044, 0xf49f, 0x4b60, { 0x8d, 0xd4, 0x5e, 0x7e, 0x3a, 0x63, 0x2a, 0xc0 } };
+static const GUID SDL_IID_IDXGIFactory2 = { 0x50c83a1c, 0xe072, 0x4c48, { 0x87, 0xb0, 0x36, 0x30, 0xfa, 0x36, 0xa6, 0xd0 } };
 
 /* SDL includes */
 extern "C" {
@@ -63,6 +59,7 @@ extern "C" {
 #include "SDL_syswm.h"
 #include "SDL_winrtopengles.h"
 #include "../../core/windows/SDL_windows.h"
+#include "SDL_winrtmessagebox.h"
 }
 
 #include "../../core/winrt/SDL_winrtapp_direct3d.h"
@@ -75,14 +72,12 @@ extern "C" {
 #include "SDL_system.h"
 #include "SDL_hints.h"
 
-
 /* Initialization/Query functions */
 static int WINRT_VideoInit(_THIS);
 static int WINRT_InitModes(_THIS);
-static int WINRT_SetDisplayMode(_THIS, SDL_VideoDisplay * display, SDL_DisplayMode * mode);
+static int WINRT_SetDisplayMode(_THIS, SDL_VideoDisplay *display, SDL_DisplayMode *mode);
 static void WINRT_VideoQuit(_THIS);
 
-
 /* Window functions */
 static int WINRT_CreateWindow(_THIS, SDL_Window * window);
 static void WINRT_SetWindowSize(_THIS, SDL_Window * window);
@@ -92,21 +87,18 @@ static SDL_bool WINRT_GetWindowWMInfo(_THIS, SDL_Window * window, SDL_SysWMinfo
 
 
 /* Misc functions */
-static ABI::Windows::System::Display::IDisplayRequest * WINRT_CreateDisplayRequest(_THIS);
+static ABI::Windows::System::Display::IDisplayRequest *WINRT_CreateDisplayRequest(_THIS);
 extern void WINRT_SuspendScreenSaver(_THIS);
 
-
 /* SDL-internal globals: */
-SDL_Window * WINRT_GlobalSDLWindow = NULL;
-
+SDL_Window *WINRT_GlobalSDLWindow = NULL;
 
 /* WinRT driver bootstrap functions */
 
-static void
-WINRT_DeleteDevice(SDL_VideoDevice * device)
+static void WINRT_DeleteDevice(SDL_VideoDevice *device)
 {
     if (device->driverdata) {
-        SDL_VideoData * video_data = (SDL_VideoData *)device->driverdata;
+        SDL_VideoData *video_data = (SDL_VideoData *)device->driverdata;
         if (video_data->winrtEglWindow) {
             video_data->winrtEglWindow->Release();
         }
@@ -116,24 +108,23 @@ WINRT_DeleteDevice(SDL_VideoDevice * device)
     SDL_free(device);
 }
 
-static SDL_VideoDevice *
-WINRT_CreateDevice(void)
+static SDL_VideoDevice *WINRT_CreateDevice(void)
 {
     SDL_VideoDevice *device;
     SDL_VideoData *data;
 
     /* Initialize all variables that we clean on shutdown */
-    device = (SDL_VideoDevice *) SDL_calloc(1, sizeof(SDL_VideoDevice));
+    device = (SDL_VideoDevice *)SDL_calloc(1, sizeof(SDL_VideoDevice));
     if (!device) {
         SDL_OutOfMemory();
-        return (0);
+        return 0;
     }
 
-    data = (SDL_VideoData *) SDL_calloc(1, sizeof(SDL_VideoData));
+    data = (SDL_VideoData *)SDL_calloc(1, sizeof(SDL_VideoData));
     if (!data) {
         SDL_OutOfMemory();
         SDL_free(device);
-        return (0);
+        return 0;
     }
     device->driverdata = data;
 
@@ -174,14 +165,13 @@ WINRT_CreateDevice(void)
     return device;
 }
 
-#define WINRTVID_DRIVER_NAME "winrt"
 VideoBootStrap WINRT_bootstrap = {
-    WINRTVID_DRIVER_NAME, "SDL WinRT video driver",
-    WINRT_CreateDevice
+    "winrt", "SDL WinRT video driver",
+    WINRT_CreateDevice,
+    WINRT_ShowMessageBox
 };
 
-static void SDLCALL
-WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const char *oldValue, const char *newValue)
+static void SDLCALL WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const char *oldValue, const char *newValue)
 {
     SDL_assert(SDL_strcmp(name, SDL_HINT_ORIENTATIONS) == 0);
 
@@ -191,7 +181,7 @@ WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const c
      *
      * TODO, WinRT: consider reading in an app's .appxmanifest file, and apply its orientation when 'newValue == NULL'.
      */
-    if ((oldValue == NULL) && (newValue == NULL)) {
+    if ((!oldValue) && (!newValue)) {
         return;
     }
 
@@ -204,13 +194,13 @@ WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const c
             std::string orientationName;
             std::getline(tokenizer, orientationName, ' ');
             if (orientationName == "LandscapeLeft") {
-                orientationFlags |= (unsigned int) DisplayOrientations::LandscapeFlipped;
+                orientationFlags |= (unsigned int)DisplayOrientations::LandscapeFlipped;
             } else if (orientationName == "LandscapeRight") {
-                orientationFlags |= (unsigned int) DisplayOrientations::Landscape;
+                orientationFlags |= (unsigned int)DisplayOrientations::Landscape;
             } else if (orientationName == "Portrait") {
-                orientationFlags |= (unsigned int) DisplayOrientations::Portrait;
+                orientationFlags |= (unsigned int)DisplayOrientations::Portrait;
             } else if (orientationName == "PortraitUpsideDown") {
-                orientationFlags |= (unsigned int) DisplayOrientations::PortraitFlipped;
+                orientationFlags |= (unsigned int)DisplayOrientations::PortraitFlipped;
             }
         }
     }
@@ -218,11 +208,10 @@ WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const c
     // If no valid orientation flags were specified, use a reasonable set of defaults:
     if (!orientationFlags) {
         // TODO, WinRT: consider seeing if an app's default orientation flags can be found out via some API call(s).
-        orientationFlags = (unsigned int) ( \
-            DisplayOrientations::Landscape |
-            DisplayOrientations::LandscapeFlipped |
-            DisplayOrientations::Portrait |
-            DisplayOrientations::PortraitFlipped);
+        orientationFlags = (unsigned int)(DisplayOrientations::Landscape |
+                                          DisplayOrientations::LandscapeFlipped |
+                                          DisplayOrientations::Portrait |
+                                          DisplayOrientations::PortraitFlipped);
     }
 
     // Set the orientation/rotation preferences.  Please note that this does
@@ -239,13 +228,12 @@ WINRT_SetDisplayOrientationsPreference(void *userdata, const char *name, const c
     // for details.  Microsoft's "Display orientation sample" also gives an
     // outline of how Windows treats device rotation
     // (http://code.msdn.microsoft.com/Display-Orientation-Sample-19a58e93).
-    WINRT_DISPLAY_PROPERTY(AutoRotationPreferences) = (DisplayOrientations) orientationFlags;
+    WINRT_DISPLAY_PROPERTY(AutoRotationPreferences) = (DisplayOrientations)orientationFlags;
 }
 
-int
-WINRT_VideoInit(_THIS)
+int WINRT_VideoInit(_THIS)
 {
-    SDL_VideoData * driverdata = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     if (WINRT_InitModes(_this) < 0) {
         return -1;
     }
@@ -264,11 +252,9 @@ WINRT_VideoInit(_THIS)
     return 0;
 }
 
-extern "C"
-Uint32 D3D11_DXGIFormatToSDLPixelFormat(DXGI_FORMAT dxgiFormat);
+extern "C" Uint32 D3D11_DXGIFormatToSDLPixelFormat(DXGI_FORMAT dxgiFormat);
 
-static void
-WINRT_DXGIModeToSDLDisplayMode(const DXGI_MODE_DESC * dxgiMode, SDL_DisplayMode * sdlMode)
+static void WINRT_DXGIModeToSDLDisplayMode(const DXGI_MODE_DESC *dxgiMode, SDL_DisplayMode *sdlMode)
 {
     SDL_zerop(sdlMode);
     sdlMode->w = dxgiMode->Width;
@@ -277,17 +263,16 @@ WINRT_DXGIModeToSDLDisplayMode(const DXGI_MODE_DESC * dxgiMode, SDL_DisplayMode
     sdlMode->format = D3D11_DXGIFormatToSDLPixelFormat(dxgiMode->Format);
 }
 
-static int
-WINRT_AddDisplaysForOutput (_THIS, IDXGIAdapter1 * dxgiAdapter1, int outputIndex)
+static int WINRT_AddDisplaysForOutput(_THIS, IDXGIAdapter1 *dxgiAdapter1, int outputIndex)
 {
     HRESULT hr;
-    IDXGIOutput * dxgiOutput = NULL;
+    IDXGIOutput *dxgiOutput = NULL;
     DXGI_OUTPUT_DESC dxgiOutputDesc;
     SDL_VideoDisplay display;
-    char * displayName = NULL;
+    char *displayName = NULL;
     UINT numModes;
-    DXGI_MODE_DESC * dxgiModes = NULL;
-    int functionResult = -1;        /* -1 for failure, 0 for success */
+    DXGI_MODE_DESC *dxgiModes = NULL;
+    int functionResult = -1; /* -1 for failure, 0 for success */
     DXGI_MODE_DESC modeToMatch, closestMatch;
 
     SDL_zero(display);
@@ -326,17 +311,17 @@ WINRT_AddDisplaysForOutput (_THIS, IDXGIAdapter1 * dxgiAdapter1, int outputIndex
         mode.w = (dxgiOutputDesc.DesktopCoordinates.right - dxgiOutputDesc.DesktopCoordinates.left);
         mode.h = (dxgiOutputDesc.DesktopCoordinates.bottom - dxgiOutputDesc.DesktopCoordinates.top);
         mode.format = DXGI_FORMAT_B8G8R8A8_UNORM;
-        mode.refresh_rate = 0;  /* Display mode is unknown, so just fill in zero, as specified by SDL's header files */
+        mode.refresh_rate = 0; /* Display mode is unknown, so just fill in zero, as specified by SDL's header files */
         display.desktop_mode = mode;
         display.current_mode = mode;
-        if ( ! SDL_AddDisplayMode(&display, &mode)) {
+        if (!SDL_AddDisplayMode(&display, &mode)) {
             goto done;
         }
     } else if (FAILED(hr)) {
         WIN_SetErrorFromHRESULT(__FUNCTION__ ", IDXGIOutput::FindClosestMatchingMode failed", hr);
         goto done;
     } else {
-        displayName = WIN_StringToUTF8(dxgiOutputDesc.DeviceName);
+        displayName = WIN_StringToUTF8W(dxgiOutputDesc.DeviceName);
         display.name = displayName;
         WINRT_DXGIModeToSDLDisplayMode(&closestMatch, &display.desktop_mode);
         display.current_mode = display.desktop_mode;
@@ -351,7 +336,7 @@ WINRT_AddDisplaysForOutput (_THIS, IDXGIAdapter1 * dxgiAdapter1, int outputIndex
         }
 
         dxgiModes = (DXGI_MODE_DESC *)SDL_calloc(numModes, sizeof(DXGI_MODE_DESC));
-        if ( ! dxgiModes) {
+        if (!dxgiModes) {
             SDL_OutOfMemory();
             goto done;
         }
@@ -373,7 +358,7 @@ WINRT_AddDisplaysForOutput (_THIS, IDXGIAdapter1 * dxgiAdapter1, int outputIndex
         goto done;
     }
 
-    functionResult = 0;     /* 0 for Success! */
+    functionResult = 0; /* 0 for Success! */
 done:
     if (dxgiModes) {
         SDL_free(dxgiModes);
@@ -387,11 +372,10 @@ done:
     return functionResult;
 }
 
-static int
-WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterIndex)
+static int WINRT_AddDisplaysForAdapter(_THIS, IDXGIFactory2 *dxgiFactory2, int adapterIndex)
 {
     HRESULT hr;
-    IDXGIAdapter1 * dxgiAdapter1;
+    IDXGIAdapter1 *dxgiAdapter1;
 
     hr = dxgiFactory2->EnumAdapters1(adapterIndex, &dxgiAdapter1);
     if (FAILED(hr)) {
@@ -401,7 +385,7 @@ WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterInd
         return -1;
     }
 
-    for (int outputIndex = 0; ; ++outputIndex) {
+    for (int outputIndex = 0;; ++outputIndex) {
         if (WINRT_AddDisplaysForOutput(_this, dxgiAdapter1, outputIndex) < 0) {
             /* HACK: The Windows App Certification Kit 10.0 can fail, when
                running the Store Apps' test, "Direct3D Feature Test".  The
@@ -421,7 +405,7 @@ WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterInd
             if (adapterIndex == 0 && outputIndex == 0) {
                 SDL_VideoDisplay display;
                 SDL_DisplayMode mode;
-#if SDL_WINRT_USE_APPLICATIONVIEW
+#ifdef SDL_WINRT_USE_APPLICATIONVIEW
                 ApplicationView ^ appView = ApplicationView::GetForCurrentView();
 #endif
                 CoreWindow ^ coreWin = CoreWindow::GetForCurrentThread();
@@ -436,7 +420,7 @@ WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterInd
                    failing test), whereas CoreWindow might not.  -- DavidL
                 */
 
-#if (NTDDI_VERSION >= NTDDI_WIN10) || (SDL_WINRT_USE_APPLICATIONVIEW && WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP)
+#if (NTDDI_VERSION >= NTDDI_WIN10) || (defined(SDL_WINRT_USE_APPLICATIONVIEW) && SDL_WINAPI_FAMILY_PHONE)
                 mode.w = WINRT_DIPS_TO_PHYSICAL_PIXELS(appView->VisibleBounds.Width);
                 mode.h = WINRT_DIPS_TO_PHYSICAL_PIXELS(appView->VisibleBounds.Height);
 #else
@@ -448,12 +432,11 @@ WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterInd
 #endif
 
                 mode.format = DXGI_FORMAT_B8G8R8A8_UNORM;
-                mode.refresh_rate = 0;  /* Display mode is unknown, so just fill in zero, as specified by SDL's header files */
+                mode.refresh_rate = 0; /* Display mode is unknown, so just fill in zero, as specified by SDL's header files */
                 display.desktop_mode = mode;
                 display.current_mode = mode;
                 if ((SDL_AddDisplayMode(&display, &mode) < 0) ||
-                    (SDL_AddVideoDisplay(&display, SDL_FALSE) < 0))
-                {
+                    (SDL_AddVideoDisplay(&display, SDL_FALSE) < 0)) {
                     return SDL_SetError("Failed to apply DXGI Display-detection workaround");
                 }
             }
@@ -466,8 +449,7 @@ WINRT_AddDisplaysForAdapter (_THIS, IDXGIFactory2 * dxgiFactory2, int adapterInd
     return 0;
 }
 
-int
-WINRT_InitModes(_THIS)
+int WINRT_InitModes(_THIS)
 {
     /* HACK: Initialize a single display, for whatever screen the app's
          CoreApplicationView is on.
@@ -476,14 +458,14 @@ WINRT_InitModes(_THIS)
     */
 
     HRESULT hr;
-    IDXGIFactory2 * dxgiFactory2 = NULL;
+    IDXGIFactory2 *dxgiFactory2 = NULL;
 
     hr = CreateDXGIFactory1(SDL_IID_IDXGIFactory2, (void **)&dxgiFactory2);
     if (FAILED(hr)) {
         return WIN_SetErrorFromHRESULT(__FUNCTION__ ", CreateDXGIFactory1() failed", hr);
     }
 
-    for (int adapterIndex = 0; ; ++adapterIndex) {
+    for (int adapterIndex = 0;; ++adapterIndex) {
         if (WINRT_AddDisplaysForAdapter(_this, dxgiFactory2, adapterIndex) < 0) {
             break;
         }
@@ -492,16 +474,14 @@ WINRT_InitModes(_THIS)
     return 0;
 }
 
-static int
-WINRT_SetDisplayMode(_THIS, SDL_VideoDisplay * display, SDL_DisplayMode * mode)
+static int WINRT_SetDisplayMode(_THIS, SDL_VideoDisplay *display, SDL_DisplayMode *mode)
 {
     return 0;
 }
 
-void
-WINRT_VideoQuit(_THIS)
+void WINRT_VideoQuit(_THIS)
 {
-    SDL_VideoData * driverdata = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     if (driverdata && driverdata->displayRequest) {
         driverdata->displayRequest->Release();
         driverdata->displayRequest = NULL;
@@ -510,52 +490,47 @@ WINRT_VideoQuit(_THIS)
     WINRT_QuitMouse(_this);
 }
 
-static const Uint32 WINRT_DetectableFlags =
-    SDL_WINDOW_MAXIMIZED |
-    SDL_WINDOW_FULLSCREEN_DESKTOP |
-    SDL_WINDOW_SHOWN |
-    SDL_WINDOW_HIDDEN |
-    SDL_WINDOW_MOUSE_FOCUS;
+static const Uint32 WINRT_DetectableFlags = SDL_WINDOW_MAXIMIZED | SDL_WINDOW_FULLSCREEN_DESKTOP | SDL_WINDOW_SHOWN | SDL_WINDOW_HIDDEN | SDL_WINDOW_MOUSE_FOCUS;
 
 extern "C" Uint32
-WINRT_DetectWindowFlags(SDL_Window * window)
+WINRT_DetectWindowFlags(SDL_Window *window)
 {
     Uint32 latestFlags = 0;
-    SDL_WindowData * data = (SDL_WindowData *) window->driverdata;
+    SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
     bool is_fullscreen = false;
 
-#if SDL_WINRT_USE_APPLICATIONVIEW
+#ifdef SDL_WINRT_USE_APPLICATIONVIEW
     if (data->appView) {
         is_fullscreen = data->appView->IsFullScreenMode;
     }
-#elif (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP) || (NTDDI_VERSION == NTDDI_WIN8)
+#elif SDL_WINAPI_FAMILY_PHONE || (NTDDI_VERSION == NTDDI_WIN8)
     is_fullscreen = true;
 #endif
 
     if (data->coreWindow.Get()) {
         if (is_fullscreen) {
-            SDL_VideoDisplay * display = SDL_GetDisplayForWindow(window);
+            SDL_VideoDisplay *display = SDL_GetDisplayForWindow(window);
             int w = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Width);
             int h = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Height);
 
-#if (WINAPI_FAMILY != WINAPI_FAMILY_PHONE_APP) || (NTDDI_VERSION > NTDDI_WIN8)
+#if !SDL_WINAPI_FAMILY_PHONE || (NTDDI_VERSION > NTDDI_WIN8)
             // On all WinRT platforms, except for WinPhone 8.0, rotate the
             // window size.  This is needed to properly calculate
             // fullscreen vs. maximized.
             const DisplayOrientations currentOrientation = WINRT_DISPLAY_PROPERTY(CurrentOrientation);
             switch (currentOrientation) {
-#if (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP)
-                case DisplayOrientations::Landscape:
-                case DisplayOrientations::LandscapeFlipped:
+#if SDL_WINAPI_FAMILY_PHONE
+            case DisplayOrientations::Landscape:
+            case DisplayOrientations::LandscapeFlipped:
 #else
-                case DisplayOrientations::Portrait:
-                case DisplayOrientations::PortraitFlipped:
+            case DisplayOrientations::Portrait:
+            case DisplayOrientations::PortraitFlipped:
 #endif
-                {
-                    int tmp = w;
-                    w = h;
-                    h = tmp;
-                } break;
+            {
+                int tmp = w;
+                w = h;
+                h = tmp;
+            } break;
             }
 #endif
 
@@ -572,7 +547,7 @@ WINRT_DetectWindowFlags(SDL_Window * window)
             latestFlags |= SDL_WINDOW_HIDDEN;
         }
 
-#if (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP) && (NTDDI_VERSION < NTDDI_WINBLUE)
+#if SDL_WINAPI_FAMILY_PHONE && (NTDDI_VERSION < NTDDI_WINBLUE)
         // data->coreWindow->PointerPosition is not supported on WinPhone 8.0
         latestFlags |= SDL_WINDOW_MOUSE_FOCUS;
 #else
@@ -586,47 +561,44 @@ WINRT_DetectWindowFlags(SDL_Window * window)
 }
 
 // TODO, WinRT: consider removing WINRT_UpdateWindowFlags, and just calling WINRT_DetectWindowFlags as-appropriate (with appropriate calls to SDL_SendWindowEvent)
-void
-WINRT_UpdateWindowFlags(SDL_Window * window, Uint32 mask)
+void WINRT_UpdateWindowFlags(SDL_Window *window, Uint32 mask)
 {
     mask &= WINRT_DetectableFlags;
     if (window) {
         Uint32 apply = WINRT_DetectWindowFlags(window);
         if ((apply & mask) & SDL_WINDOW_FULLSCREEN) {
-            window->last_fullscreen_flags = window->flags;  // seems necessary to programmatically un-fullscreen, via SDL APIs
+            window->last_fullscreen_flags = window->flags; // seems necessary to programmatically un-fullscreen, via SDL APIs
         }
         window->flags = (window->flags & ~mask) | (apply & mask);
     }
 }
 
-static bool
-WINRT_IsCoreWindowActive(CoreWindow ^ coreWindow)
+static bool WINRT_IsCoreWindowActive(CoreWindow ^ coreWindow)
 {
     /* WinRT does not appear to offer API(s) to determine window-activation state,
        at least not that I am aware of in Win8 - Win10.  As such, SDL tracks this
        itself, via window-activation events.
-       
+
        If there *is* an API to track this, it should probably get used instead
        of the following hack (that uses "SDLHelperWindowActivationState").
          -- DavidL.
     */
     if (coreWindow->CustomProperties->HasKey("SDLHelperWindowActivationState")) {
-        CoreWindowActivationState activationState = \
+        CoreWindowActivationState activationState =
             safe_cast<CoreWindowActivationState>(coreWindow->CustomProperties->Lookup("SDLHelperWindowActivationState"));
-        return (activationState != CoreWindowActivationState::Deactivated);
+        return activationState != CoreWindowActivationState::Deactivated;
     }
 
     /* Assume that non-SDL tracked windows are active, although this should
        probably be avoided, if possible.
-       
+
        This might not even be possible, in normal SDL use, at least as of
        this writing (Dec 22, 2015; via latest hg.libsdl.org/SDL clone)  -- DavidL
     */
     return true;
 }
 
-int
-WINRT_CreateWindow(_THIS, SDL_Window * window)
+int WINRT_CreateWindow(_THIS, SDL_Window *window)
 {
     // Make sure that only one window gets created, at least until multimonitor
     // support is added.
@@ -634,7 +606,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
         return SDL_SetError("WinRT only supports one window");
     }
 
-    SDL_WindowData *data = new SDL_WindowData;  /* use 'new' here as SDL_WindowData may use WinRT/C++ types */
+    SDL_WindowData *data = new SDL_WindowData; /* use 'new' here as SDL_WindowData may use WinRT/C++ types */
     if (!data) {
         return SDL_OutOfMemory();
     }
@@ -649,7 +621,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
     */
     if (!WINRT_XAMLWasEnabled) {
         data->coreWindow = CoreWindow::GetForCurrentThread();
-#if SDL_WINRT_USE_APPLICATIONVIEW
+#ifdef SDL_WINRT_USE_APPLICATIONVIEW
         data->appView = ApplicationView::GetForCurrentView();
 #endif
     }
@@ -657,14 +629,14 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
     /* Make note of the requested window flags, before they start getting changed. */
     const Uint32 requestedFlags = window->flags;
 
-#if SDL_VIDEO_OPENGL_EGL
+#ifdef SDL_VIDEO_OPENGL_EGL
     /* Setup the EGL surface, but only if OpenGL ES 2 was requested. */
     if (!(window->flags & SDL_WINDOW_OPENGL)) {
         /* OpenGL ES 2 wasn't requested.  Don't set up an EGL surface. */
         data->egl_surface = EGL_NO_SURFACE;
     } else {
         /* OpenGL ES 2 was reuqested.  Set up an EGL surface. */
-        SDL_VideoData * video_data = (SDL_VideoData *)_this->driverdata;
+        SDL_VideoData *video_data = (SDL_VideoData *)_this->driverdata;
 
         /* Call SDL_EGL_ChooseConfig and eglCreateWindowSurface directly,
          * rather than via SDL_EGL_CreateSurface, as older versions of
@@ -673,10 +645,10 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
          */
         if (SDL_EGL_ChooseConfig(_this) != 0) {
             /* SDL_EGL_ChooseConfig failed, SDL_GetError() should have info */
-            return -1; 
+            return -1;
         }
 
-        if (video_data->winrtEglWindow) {   /* ... is the 'old' version of ANGLE/WinRT being used? */
+        if (video_data->winrtEglWindow) { /* ... is the 'old' version of ANGLE/WinRT being used? */
             /* Attempt to create a window surface using older versions of
              * ANGLE/WinRT:
              */
@@ -692,7 +664,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
             /* Attempt to create a window surface using newer versions of
              * ANGLE/WinRT:
              */
-            IInspectable * coreWindowAsIInspectable = reinterpret_cast<IInspectable *>(data->coreWindow.Get());
+            IInspectable *coreWindowAsIInspectable = reinterpret_cast<IInspectable *>(data->coreWindow.Get());
             data->egl_surface = _this->egl_data->eglCreateWindowSurface(
                 _this->egl_data->egl_display,
                 _this->egl_data->egl_config,
@@ -712,7 +684,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
         SDL_WINDOW_BORDERLESS |
         SDL_WINDOW_RESIZABLE;
 
-#if SDL_VIDEO_OPENGL_EGL
+#ifdef SDL_VIDEO_OPENGL_EGL
     if (data->egl_surface) {
         window->flags |= SDL_WINDOW_OPENGL;
     }
@@ -723,8 +695,8 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
         window->x = 0;
         window->y = 0;
         window->flags |= SDL_WINDOW_SHOWN;
-        SDL_SetMouseFocus(NULL);        // TODO: detect this
-        SDL_SetKeyboardFocus(NULL);     // TODO: detect this
+        SDL_SetMouseFocus(NULL);    // TODO: detect this
+        SDL_SetKeyboardFocus(NULL); // TODO: detect this
     } else {
         /* WinRT 8.x apps seem to live in an environment where the OS controls the
            app's window size, with some apps being fullscreen, depending on
@@ -758,7 +730,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
 
         WINRT_UpdateWindowFlags(
             window,
-            0xffffffff      /* Update any window flag(s) that WINRT_UpdateWindow can handle */
+            0xffffffff /* Update any window flag(s) that WINRT_UpdateWindow can handle */
         );
 
         /* Try detecting if the window is active */
@@ -767,7 +739,7 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
             SDL_SetKeyboardFocus(window);
         }
     }
- 
+
     /* Make sure the WinRT app's IFramworkView can post events on
        behalf of SDL:
     */
@@ -777,27 +749,25 @@ WINRT_CreateWindow(_THIS, SDL_Window * window)
     return 0;
 }
 
-void
-WINRT_SetWindowSize(_THIS, SDL_Window * window)
+void WINRT_SetWindowSize(_THIS, SDL_Window *window)
 {
 #if NTDDI_VERSION >= NTDDI_WIN10
-    SDL_WindowData * data = (SDL_WindowData *)window->driverdata;
+    SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
     const Windows::Foundation::Size size(WINRT_PHYSICAL_PIXELS_TO_DIPS(window->w),
                                          WINRT_PHYSICAL_PIXELS_TO_DIPS(window->h));
     data->appView->TryResizeView(size); // TODO, WinRT: return failure (to caller?) from TryResizeView()
 #endif
 }
 
-void
-WINRT_SetWindowFullscreen(_THIS, SDL_Window * window, SDL_VideoDisplay * display, SDL_bool fullscreen)
+void WINRT_SetWindowFullscreen(_THIS, SDL_Window *window, SDL_VideoDisplay *display, SDL_bool fullscreen)
 {
 #if NTDDI_VERSION >= NTDDI_WIN10
-    SDL_WindowData * data = (SDL_WindowData *)window->driverdata;
+    SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
     bool isWindowActive = WINRT_IsCoreWindowActive(data->coreWindow.Get());
     if (isWindowActive) {
         if (fullscreen) {
             if (!data->appView->IsFullScreenMode) {
-                data->appView->TryEnterFullScreenMode();    // TODO, WinRT: return failure (to caller?) from TryEnterFullScreenMode()
+                data->appView->TryEnterFullScreenMode(); // TODO, WinRT: return failure (to caller?) from TryEnterFullScreenMode()
             }
         } else {
             if (data->appView->IsFullScreenMode) {
@@ -808,11 +778,9 @@ WINRT_SetWindowFullscreen(_THIS, SDL_Window * window, SDL_VideoDisplay * display
 #endif
 }
 
-
-void
-WINRT_DestroyWindow(_THIS, SDL_Window * window)
+void WINRT_DestroyWindow(_THIS, SDL_Window *window)
 {
-    SDL_WindowData * data = (SDL_WindowData *) window->driverdata;
+    SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
 
     if (WINRT_GlobalSDLWindow == window) {
         WINRT_GlobalSDLWindow = NULL;
@@ -826,8 +794,7 @@ WINRT_DestroyWindow(_THIS, SDL_Window * window)
     }
 }
 
-SDL_bool
-WINRT_GetWindowWMInfo(_THIS, SDL_Window * window, SDL_SysWMinfo * info)
+SDL_bool WINRT_GetWindowWMInfo(_THIS, SDL_Window * window, SDL_SysWMinfo * info)
 {
     SDL_WindowData * data = (SDL_WindowData *) window->driverdata;
 
@@ -843,15 +810,14 @@ WINRT_GetWindowWMInfo(_THIS, SDL_Window * window, SDL_SysWMinfo * info)
     return SDL_FALSE;
 }
 
-static ABI::Windows::System::Display::IDisplayRequest *
-WINRT_CreateDisplayRequest(_THIS)
+static ABI::Windows::System::Display::IDisplayRequest *WINRT_CreateDisplayRequest(_THIS)
 {
     /* Setup a WinRT DisplayRequest object, usable for enabling/disabling screensaver requests */
     wchar_t *wClassName = L"Windows.System.Display.DisplayRequest";
     HSTRING hClassName;
     IActivationFactory *pActivationFactory = NULL;
-    IInspectable * pDisplayRequestRaw = nullptr;
-    ABI::Windows::System::Display::IDisplayRequest * pDisplayRequest = nullptr;
+    IInspectable *pDisplayRequestRaw = nullptr;
+    ABI::Windows::System::Display::IDisplayRequest *pDisplayRequest = nullptr;
     HRESULT hr;
 
     hr = ::WindowsCreateString(wClassName, (UINT32)SDL_wcslen(wClassName), &hClassName);
@@ -869,7 +835,7 @@ WINRT_CreateDisplayRequest(_THIS)
         goto done;
     }
 
-    hr = pDisplayRequestRaw->QueryInterface(SDL_IID_IDisplayRequest, (void **) &pDisplayRequest);
+    hr = pDisplayRequestRaw->QueryInterface(SDL_IID_IDisplayRequest, (void **)&pDisplayRequest);
     if (FAILED(hr)) {
         goto done;
     }
@@ -888,12 +854,11 @@ done:
     return pDisplayRequest;
 }
 
-void
-WINRT_SuspendScreenSaver(_THIS)
+void WINRT_SuspendScreenSaver(_THIS)
 {
     SDL_VideoData *driverdata = (SDL_VideoData *)_this->driverdata;
     if (driverdata && driverdata->displayRequest) {
-        ABI::Windows::System::Display::IDisplayRequest * displayRequest = (ABI::Windows::System::Display::IDisplayRequest *) driverdata->displayRequest;
+        ABI::Windows::System::Display::IDisplayRequest *displayRequest = (ABI::Windows::System::Display::IDisplayRequest *)driverdata->displayRequest;
         if (_this->suspend_screensaver) {
             displayRequest->RequestActive();
         } else {
